@@ -125,14 +125,25 @@ make_url.default <- function(x) {
 #'
 make_url.otpconnect <- function(x) {
   if (is.null(x$url)) {
-    url <- paste0(
-      ifelse(isTRUE(x$ssl), "https://", "http://"),
-      x$hostname,
-      ":",
-      x$port,
-      "/otp/routers/",
-      x$router
-    )
+    if (x$ssl) {
+      url <- paste0(
+        "https://",
+        x$hostname,
+        ":",
+        x$port,
+        "/otp/routers/",
+        x$router
+      )
+    } else {
+      url <- paste0(
+        "http://",
+        x$hostname,
+        ":",
+        x$port,
+        "/otp/routers/",
+        x$router
+      )
+    }
   } else {
     url <- x$url
   }
@@ -141,6 +152,7 @@ make_url.otpconnect <- function(x) {
 }
 
 
+
 #' otpconnect method to check if router exists
 #' @param x otpcon
 #' @family internal
@@ -170,7 +182,7 @@ check_router.default <- function(x) {
 #' @noRd
 #'
 check_router.otpconnect <- function(x) {
-  check <- try(httr::GET(make_url(x)), silent = TRUE)
+  check <- try(curl::curl_fetch_memory(make_url(x)), silent = TRUE)
   if (class(check) == "try-error") {
     return(check[1])
   } else {
